@@ -14,23 +14,30 @@ from holmes.handlers import BaseHandler
 class WorkerHandler(BaseHandler):
 
     @gen.coroutine
-    def post(self, uuid):
+    def post(self, uuid, i_am='alive'):
         worker_uuid = UUID(uuid)
 
         worker = yield Worker.objects.get(uuid=worker_uuid)
 
         if worker:
-            worker.last_ping = datetime.now()
-            yield worker.save()
+            if i_am == 'alive':
+                worker.last_ping = datetime.now()
+                yield worker.save()
+            elif i_am == 'dead':
+                yield worker.delete()
         else:
             yield Worker.objects.create(uuid=worker_uuid)
 
-        dt = datetime.now() - timedelta(seconds=self.application.config.ZOMBIE_WORKER_TIME)
-        yield Worker.objects.filter(last_ping__lt=dt).delete()
+        self._remove_zombies_workers()
 
         self.write(str(worker_uuid))
         self.finish()
 
+    @gen.coroutine
+    def _remove_zombies_workers(self):
+        dt = datetime.now() - timedelta(seconds=self.application.config.ZOMBIE_WORKER_TIME)
+        yield Worker.objects.filter(last_ping__lt=dt).delete()
+
 
 class WorkersHandler(BaseHandler):
 
